# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
from typing import Optional

import pulumi
import pulumi.runtime
from pulumi import Input, ResourceOptions

from ... import tables, version


class ConfigMap(pulumi.CustomResource):
    """
    ConfigMap holds configuration data for pods to consume.
    """

    apiVersion: pulumi.Output[str]
    """
    APIVersion defines the versioned schema of this representation of an object. Servers should
    convert recognized schemas to the latest internal value, and may reject unrecognized values.
    More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources
    """

    kind: pulumi.Output[str]
    """
    Kind is a string value representing the REST resource this object represents. Servers may infer
    this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More
    info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
    """

    binary_data: pulumi.Output[dict]
    """
    BinaryData contains the binary data. Each key must consist of alphanumeric characters, '-', '_'
    or '.'. BinaryData can contain byte sequences that are not in the UTF-8 range. The keys stored
    in BinaryData must not overlap with the ones in the Data field, this is enforced during
    validation process. Using this field will require 1.10+ apiserver and kubelet.
    """

    data: pulumi.Output[dict]
    """
    Data contains the configuration data. Each key must consist of alphanumeric characters, '-', '_'
    or '.'. Values with non-UTF-8 byte sequences must use the BinaryData field. The keys stored in
    Data must not overlap with the keys in the BinaryData field, this is enforced during validation
    process.
    """

    immutable: pulumi.Output[bool]
    """
    Immutable, if set to true, ensures that data stored in the ConfigMap cannot be updated (only
    object metadata can be modified). If not set to true, the field can be modified at any time.
    Defaulted to nil. This is an alpha field enabled by ImmutableEphemeralVolumes feature gate.
    """

    metadata: pulumi.Output[dict]
    """
    Standard object's metadata. More info:
    https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """

    def __init__(self, resource_name, opts=None, binary_data=None, data=None, immutable=None, metadata=None, __name__=None, __opts__=None):
        """
        Create a ConfigMap resource with the given unique name, arguments, and options.

        :param str resource_name: The _unique_ name of the resource.
        :param pulumi.ResourceOptions opts: A bag of options that control this resource's behavior.
        :param pulumi.Input[dict] binary_data: BinaryData contains the binary data. Each key must consist of alphanumeric
               characters, '-', '_' or '.'. BinaryData can contain byte sequences that are not in
               the UTF-8 range. The keys stored in BinaryData must not overlap with the ones in the
               Data field, this is enforced during validation process. Using this field will require
               1.10+ apiserver and kubelet.
        :param pulumi.Input[dict] data: Data contains the configuration data. Each key must consist of alphanumeric
               characters, '-', '_' or '.'. Values with non-UTF-8 byte sequences must use the
               BinaryData field. The keys stored in Data must not overlap with the keys in the
               BinaryData field, this is enforced during validation process.
        :param pulumi.Input[bool] immutable: Immutable, if set to true, ensures that data stored in the ConfigMap cannot be
               updated (only object metadata can be modified). If not set to true, the field can be
               modified at any time. Defaulted to nil. This is an alpha field enabled by
               ImmutableEphemeralVolumes feature gate.
        :param pulumi.Input[dict] metadata: Standard object's metadata. More info:
               https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'v1'
        __props__['kind'] = 'ConfigMap'
        __props__['binaryData'] = binary_data
        __props__['data'] = data
        __props__['immutable'] = immutable
        __props__['metadata'] = metadata

        __props__['status'] = None

        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(
            version=version.get_version(),
        ))

        super(ConfigMap, self).__init__(
            "kubernetes:core/v1:ConfigMap",
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None):
        """
        Get the state of an existing `ConfigMap` resource, as identified by `id`.
        The ID is of the form `[namespace]/[name]`; if `[namespace]` is omitted,
        then (per Kubernetes convention) the ID becomes `default/[name]`.

        Pulumi will keep track of this resource using `resource_name` as the Pulumi ID.

        :param str resource_name: _Unique_ name used to register this resource with Pulumi.
        :param pulumi.Input[str] id: An ID for the Kubernetes resource to retrieve.
               Takes the form `[namespace]/[name]` or `[name]`.
        :param Optional[pulumi.ResourceOptions] opts: A bag of options that control this
               resource's behavior.
        """
        opts = ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))
        return ConfigMap(resource_name, opts)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
from typing import Optional

import pulumi
import pulumi.runtime
from pulumi import Input, ResourceOptions

from ... import tables, version


class Status(pulumi.CustomResource):
    """
    Status is a return value for calls that don't return other objects.
    """

    apiVersion: pulumi.Output[str]
    """
    APIVersion defines the versioned schema of this representation of an object. Servers should
    convert recognized schemas to the latest internal value, and may reject unrecognized values.
    More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources
    """

    kind: pulumi.Output[str]
    """
    Kind is a string value representing the REST resource this object represents. Servers may infer
    this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More
    info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
    """

    code: pulumi.Output[int]
    """
    Suggested HTTP return code for this status, 0 if not set.
    """

    details: pulumi.Output[dict]
    """
    Extended data associated with the reason.  Each reason may define its own extended details. This
    field is optional and the data returned is not guaranteed to conform to any schema except that
    defined by the reason type.
    """

    message: pulumi.Output[str]
    """
    A human-readable description of the status of this operation.
    """

    metadata: pulumi.Output[dict]
    """
    Standard list metadata. More info:
    https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
    """

    reason: pulumi.Output[str]
    """
    A machine-readable description of why this operation is in the "Failure" status. If this value
    is empty there is no information available. A Reason clarifies an HTTP status code but does not
    override it.
    """

    status: pulumi.Output[str]
    """
    Status of the operation. One of: "Success" or "Failure". More info:
    https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status
    """

    def __init__(self, resource_name, opts=None, code=None, details=None, message=None, metadata=None, reason=None, __name__=None, __opts__=None):
        """
        Create a Status resource with the given unique name, arguments, and options.

        :param str resource_name: The _unique_ name of the resource.
        :param pulumi.ResourceOptions opts: A bag of options that control this resource's behavior.
        :param pulumi.Input[int] code: Suggested HTTP return code for this status, 0 if not set.
        :param pulumi.Input[dict] details: Extended data associated with the reason.  Each reason may define its own extended
               details. This field is optional and the data returned is not guaranteed to conform to
               any schema except that defined by the reason type.
        :param pulumi.Input[str] message: A human-readable description of the status of this operation.
        :param pulumi.Input[dict] metadata: Standard list metadata. More info:
               https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
        :param pulumi.Input[str] reason: A machine-readable description of why this operation is in the "Failure" status. If
               this value is empty there is no information available. A Reason clarifies an HTTP
               status code but does not override it.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'v1'
        __props__['kind'] = 'Status'
        __props__['code'] = code
        __props__['details'] = details
        __props__['message'] = message
        __props__['metadata'] = metadata
        __props__['reason'] = reason

        __props__['status'] = None

        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(
            version=version.get_version(),
        ))

        super(Status, self).__init__(
            "kubernetes:core/v1:Status",
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None):
        """
        Get the state of an existing `Status` resource, as identified by `id`.
        The ID is of the form `[namespace]/[name]`; if `[namespace]` is omitted,
        then (per Kubernetes convention) the ID becomes `default/[name]`.

        Pulumi will keep track of this resource using `resource_name` as the Pulumi ID.

        :param str resource_name: _Unique_ name used to register this resource with Pulumi.
        :param pulumi.Input[str] id: An ID for the Kubernetes resource to retrieve.
               Takes the form `[namespace]/[name]` or `[name]`.
        :param Optional[pulumi.ResourceOptions] opts: A bag of options that control this
               resource's behavior.
        """
        opts = ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))
        return Status(resource_name, opts)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop



import warnings

import pulumi


class Provider(pulumi.ProviderResource):
    """
    The provider type for the kubernetes package.
    """

    def __init__(self,
                 resource_name,
                 opts=None,
                 cluster=None,
                 context=None,
                 enable_dry_run=None,
                 kubeconfig=None,
                 namespace=None,
                 suppress_deprecation_warnings=None,
                 render_yaml_to_directory=None,
                 __name__=None,
                 __opts__=None):
        """
        Create a Provider resource with the given unique name, arguments, and options.

        :param str resource_name: The unique name of the resource.
        :param pulumi.ResourceOptions opts: An optional bag of options that controls this resource's behavior.
        :param pulumi.Input[str] cluster: If present, the name of the kubeconfig cluster to use.
        :param pulumi.Input[str] context: If present, the name of the kubeconfig context to use.
        :param pulumi.Input[bool] enable_dry_run: BETA FEATURE - If present and set to True, enable server-side diff
                                  calculations. This feature is in developer preview, and is disabled by default.
                                  This config can be specified in the following ways, using this precedence:
                                  1. This `enableDryRun` parameter.
                                  2. The `PULUMI_K8S_ENABLE_DRY_RUN` environment variable.
        :param pulumi.Input[str] kubeconfig: The contents of a kubeconfig file.
                                 If this is set, this config will be used instead of $KUBECONFIG.
        :param pulumi.Input[str] namespace: If present, the default namespace to use.
                                 This flag is ignored for cluster-scoped resources.
                                 A namespace can be specified in multiple places, and the precedence is as follows:
                                 1. `.metadata.namespace` set on the resource.
                                 2. This `namespace` parameter.
                                 3. `namespace` set for the active context in the kubeconfig.
        :param pulumi.Input[bool] suppress_deprecation_warnings: If present and set to True, suppress apiVersion
                                  deprecation warnings from the CLI.
                                  This config can be specified in the following ways, using this precedence:
                                  1. This `suppressDeprecationWarnings` parameter.
                                  2. The `PULUMI_K8S_SUPPRESS_DEPRECATION_WARNINGS` environment variable.
        :param pulumi.Input[str] render_yaml_to_directory: BETA FEATURE - If present, render resource manifests to this
                                 directory. In this mode, resources will not be created on a Kubernetes cluster, but
                                 the rendered manifests will be kept in sync with changes to the Pulumi program.
                                 This feature is in developer preview, and is disabled by default. Note that some
                                 computed Outputs such as status fields will not be populated since the resources are
                                 not created on a Kubernetes cluster. These Output values will remain undefined,
                                 and may result in an error if they are referenced by other resources. Also note that
                                 any secret values used in these resources will be rendered in plaintext to the
                                 resulting YAML.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        __props__ = {
            "cluster": cluster,
            "context": context,
            "enableDryRun": enable_dry_run,
            "kubeconfig": kubeconfig,
            "namespace": namespace,
            "suppressDeprecationWarnings": suppress_deprecation_warnings,
            "renderYamlToDirectory": render_yaml_to_directory,
        }
        super(Provider, self).__init__("kubernetes", resource_name, __props__, opts)



# *** WARNING: this file was generated by the Pulumi Kubernetes codegen tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
from typing import Optional

import pulumi
import pulumi.runtime
from pulumi import Input, ResourceOptions

from ... import tables, version


class Event(pulumi.CustomResource):
    """
    Event is a report of an event somewhere in the cluster.
    """

    apiVersion: pulumi.Output[str]
    """
    APIVersion defines the versioned schema of this representation of an object. Servers should
    convert recognized schemas to the latest internal value, and may reject unrecognized values.
    More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#resources
    """

    kind: pulumi.Output[str]
    """
    Kind is a string value representing the REST resource this object represents. Servers may infer
    this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More
    info: https://git.k8s.io/community/contributors/devel/api-conventions.md#types-kinds
    """

    action: pulumi.Output[str]
    """
    What action was taken/failed regarding to the Regarding object.
    """

    count: pulumi.Output[int]
    """
    The number of times this event has occurred.
    """

    event_time: pulumi.Output[str]
    """
    Time when this Event was first observed.
    """

    first_timestamp: pulumi.Output[str]
    """
    The time at which the event was first recorded. (Time of server receipt is in TypeMeta.)
    """

    involved_object: pulumi.Output[dict]
    """
    The object that this event is about.
    """

    last_timestamp: pulumi.Output[str]
    """
    The time at which the most recent occurrence of this event was recorded.
    """

    message: pulumi.Output[str]
    """
    A human-readable description of the status of this operation.
    """

    metadata: pulumi.Output[dict]
    """
    Standard object's metadata. More info:
    https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
    """

    reason: pulumi.Output[str]
    """
    This should be a short, machine understandable string that gives the reason for the transition
    into the object's current status.
    """

    related: pulumi.Output[dict]
    """
    Optional secondary object for more complex actions.
    """

    reporting_component: pulumi.Output[str]
    """
    Name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`.
    """

    reporting_instance: pulumi.Output[str]
    """
    ID of the controller instance, e.g. `kubelet-xyzf`.
    """

    series: pulumi.Output[dict]
    """
    Data about the Event series this event represents or nil if it's a singleton Event.
    """

    source: pulumi.Output[dict]
    """
    The component reporting this event. Should be a short machine understandable string.
    """

    type: pulumi.Output[str]
    """
    Type of this event (Normal, Warning), new types could be added in the future
    """

    def __init__(self, resource_name, opts=None, involved_object=None, metadata=None, action=None, count=None, event_time=None, first_timestamp=None, last_timestamp=None, message=None, reason=None, related=None, reporting_component=None, reporting_instance=None, series=None, source=None, type=None, __name__=None, __opts__=None):
        """
        Create a Event resource with the given unique name, arguments, and options.

        :param str resource_name: The _unique_ name of the resource.
        :param pulumi.ResourceOptions opts: A bag of options that control this resource's behavior.
        :param pulumi.Input[dict] involved_object: The object that this event is about.
        :param pulumi.Input[dict] metadata: Standard object's metadata. More info:
               https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
        :param pulumi.Input[str] action: What action was taken/failed regarding to the Regarding object.
        :param pulumi.Input[int] count: The number of times this event has occurred.
        :param pulumi.Input[str] event_time: Time when this Event was first observed.
        :param pulumi.Input[str] first_timestamp: The time at which the event was first recorded. (Time of server receipt is in
               TypeMeta.)
        :param pulumi.Input[str] last_timestamp: The time at which the most recent occurrence of this event was recorded.
        :param pulumi.Input[str] message: A human-readable description of the status of this operation.
        :param pulumi.Input[str] reason: This should be a short, machine understandable string that gives the reason for the
               transition into the object's current status.
        :param pulumi.Input[dict] related: Optional secondary object for more complex actions.
        :param pulumi.Input[str] reporting_component: Name of the controller that emitted this Event, e.g. `kubernetes.io/kubelet`.
        :param pulumi.Input[str] reporting_instance: ID of the controller instance, e.g. `kubelet-xyzf`.
        :param pulumi.Input[dict] series: Data about the Event series this event represents or nil if it's a singleton Event.
        :param pulumi.Input[dict] source: The component reporting this event. Should be a short machine understandable string.
        :param pulumi.Input[str] type: Type of this event (Normal, Warning), new types could be added in the future
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if not resource_name:
            raise TypeError('Missing resource name argument (for URN creation)')
        if not isinstance(resource_name, str):
            raise TypeError('Expected resource name to be a string')
        if opts and not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')

        __props__ = dict()

        __props__['apiVersion'] = 'v1'
        __props__['kind'] = 'Event'
        if involved_object is None:
            raise TypeError('Missing required property involved_object')
        __props__['involvedObject'] = involved_object
        if metadata is None:
            raise TypeError('Missing required property metadata')
        __props__['metadata'] = metadata
        __props__['action'] = action
        __props__['count'] = count
        __props__['eventTime'] = event_time
        __props__['firstTimestamp'] = first_timestamp
        __props__['lastTimestamp'] = last_timestamp
        __props__['message'] = message
        __props__['reason'] = reason
        __props__['related'] = related
        __props__['reportingComponent'] = reporting_component
        __props__['reportingInstance'] = reporting_instance
        __props__['series'] = series
        __props__['source'] = source
        __props__['type'] = type

        __props__['status'] = None

        parent = opts.parent if opts and opts.parent else None
        aliases = [
            pulumi.Alias(type_="kubernetes:events.k8s.io/v1beta1:Event"),
        ]
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(
            version=version.get_version(),
            aliases=aliases,
        ))

        super(Event, self).__init__(
            "kubernetes:core/v1:Event",
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None):
        """
        Get the state of an existing `Event` resource, as identified by `id`.
        The ID is of the form `[namespace]/[name]`; if `[namespace]` is omitted,
        then (per Kubernetes convention) the ID becomes `default/[name]`.

        Pulumi will keep track of this resource using `resource_name` as the Pulumi ID.

        :param str resource_name: _Unique_ name used to register this resource with Pulumi.
        :param pulumi.Input[str] id: An ID for the Kubernetes resource to retrieve.
               Takes the form `[namespace]/[name]` or `[name]`.
        :param Optional[pulumi.ResourceOptions] opts: A bag of options that control this
               resource's behavior.
        """
        opts = ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))
        return Event(resource_name, opts)

    def translate_output_property(self, prop: str) -> str:
        return tables._CASING_FORWARD_TABLE.get(prop) or prop

    def translate_input_property(self, prop: str) -> str:
        return tables._CASING_BACKWARD_TABLE.get(prop) or prop
